#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: cmark
version: 0.5.1
id: cmark-0.5.1-28550a213c384aabe08ba531c632e415
key: cmark_Cw1x90zMYkW9qlo27SQTs3
license: BSD3
copyright: (C) 2015 John MacFarlane
maintainer: jgm@berkeley.edu
homepage: https://github.com/jgm/commonmark-hs
synopsis: Fast, accurate CommonMark (Markdown) parser and renderer
description:
    This package provides Haskell bindings for
    <https://github.com/jgm/cmark libcmark>, the reference
    parser for <http://commonmark.org CommonMark>, a fully
    specified variant of Markdown. It includes sources for
    libcmark (0.24.1) and does not require prior installation of the
    C library.
category: Text
author: John MacFarlane
exposed: True
exposed-modules:
    CMark
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/cmark-0.5.1
library-dirs: /usr/lib/ghc-7.10.3/site-local/cmark-0.5.1
data-dir: /usr/share/arm-linux-ghc-7.10.3/cmark-0.5.1
hs-libraries: HScmark-0.5.1-Cw1x90zMYkW9qlo27SQTs3
includes:
    cmark.h
depends:
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
    text-1.2.2.0-2f82ea4adfdd656d9a8840ad2ee17cc0
haddock-interfaces: /usr/share/doc/haskell-cmark/html/cmark.haddock
haddock-html: /usr/share/doc/haskell-cmark/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
